@@ -6,12 +6,13 @@
 #' group.
 #'
 #' @param ae_data adverse event dataset
-#' @param patients patient dataset
+#' @param patient patient dataset
 #'
 #' @keywords internal
 
 ae_count <- function(ae_data, patient) {
-  max.day <- max(patient$end) # number of days
+  #max.day <- max(patient$end) # number of days
+  max.day <- max(ae_data$day_end)
   ae_data$treat <- sapply(1:nrow(ae_data), function(x) patient$treat[which(patient$ps == ae_data$patient[x])])
   all_trt <- unique(patient$treat)
   K <- length(all_trt) # (number of) unique treatment group identifiers
