@@ -1,7 +1,7 @@
-#' tone - Function that plays two different sounds for AEs
+#' tone - Function that plays two different sounds for adverse events
 #'
 #' @description
-#' Plays two different sounds (after one another) for treatment group comparison for a specific AE
+#' Plays two different sounds (after one another) for treatment group comparison for a specific adverse event
 #'
 #' @param no1 classification of the frequency of the AE in the first treatment group
 #' (0=no AE chosen, 1=no occurrence, 2=rare, 3=occasionally, 4=often)
@@ -16,5 +16,7 @@ tone <- function(no1 = 0, no2 = 0, d = 0.7) {
   if (no1 == 0) sound1 <- numeric(0) else sound1 <- sin(2 * pi * to[no1] * seq(0, d, length.out = d * 16000))
   if (no2 == 0) sound2 <- numeric(0) else sound2 <- sin(2 * pi * to[no2] * seq(0, d, length.out = d * 16000))
   sound <- c(sound1, sound2)
-  if (length(sound) > 0) audio::play(audio::audioSample(sound, 4 * 16000))
+  if (length(sound) > 0) {
+    audio::play(audio::audioSample(sound, 4 * 16000))
+  }
 }
